@@ -20,8 +20,10 @@
 
 #include <cstdio>
 #include <string>
-#include <exception>
+#include <stdexcept>
+#include <algorithm>
 #include "BShapr.hpp"
+#include "BUtilities/stof.hpp"
 
 #define LIM(g , min, max) ((g) > (max) ? (max) : ((g) < (min) ? (min) : (g)))
 #define SGN(a) ((a) < 0 ? -1 : 1)
@@ -122,7 +124,6 @@ BShapr::BShapr (double samplerate, const LV2_Feature* const* features) :
 	rate(samplerate), bpm(120.0f), speed(1), bar (0), barBeat (0), beatsPerBar (4), beatUnit (4),
 	position(0), offset(0), refFrame(0),
 	audioInput1(NULL), audioInput2(NULL), audioOutput1(NULL), audioOutput2(NULL),
-	sendValue{0xFF},
 	new_controllers {NULL}, controllers {0},
 	shapes {SmoothShape<MAXNODES> ()}, tempNodes {StaticArrayList<Node, MAXNODES> ()},
 	urids (), controlPort(NULL), notifyPort(NULL),
@@ -137,6 +138,7 @@ BShapr::BShapr (double samplerate, const LV2_Feature* const* features) :
 	scheduleNotifyStatus (true)
 
 {
+	std::fill (sendValue, sendValue + MAXSHAPES, 0xFF);
 	for (int i = 0; i < MAXSHAPES; ++i)
 	{
 		shapes[i].setDefaultShape ();
@@ -1447,7 +1449,7 @@ LV2_State_Status BShapr::state_restore (LV2_State_Retrieve_Function retrieve, LV
 			shapesDataString.erase (0, strPos + 4);
 
 			int sh;
-			try {sh = std::stof (shapesDataString, &nextPos);}
+			try {sh = BUtilities::stof (shapesDataString, &nextPos);}
 			catch  (const std::exception& e)
 			{
 				fprintf (stderr, "BShapr.lv2: Restore shape state incomplete. Can't parse shape number from \"%s...\"", shapesDataString.substr (0, 63).c_str());
@@ -1476,7 +1478,7 @@ LV2_State_Status BShapr::state_restore (LV2_State_Retrieve_Function retrieve, LV
 				}
 				if (strPos > 0) shapesDataString.erase (0, strPos + 4);
 				float val;
-				try {val = std::stof (shapesDataString, &nextPos);}
+				try {val = BUtilities::stof (shapesDataString, &nextPos);}
 				catch  (const std::exception& e)
 				{
 					fprintf (stderr, "BShapr.lv2: Restore shape state incomplete. Can't parse %s from \"%s...\"",
@@ -1539,7 +1541,7 @@ LV2_State_Status BShapr::state_restore (LV2_State_Retrieve_Function retrieve, LV
 	return LV2_STATE_SUCCESS;
 }
 
-LV2_Handle instantiate (const LV2_Descriptor* descriptor, double samplerate, const char* bundle_path, const LV2_Feature* const* features)
+static LV2_Handle instantiate (const LV2_Descriptor* descriptor, double samplerate, const char* bundle_path, const LV2_Feature* const* features)
 {
 	// New instance
 	BShapr* instance;
@@ -1566,22 +1568,22 @@ LV2_Handle instantiate (const LV2_Descriptor* descriptor, double samplerate, con
 	return (LV2_Handle)instance;
 }
 
-void connect_port (LV2_Handle instance, uint32_t port, void *data)
+static void connect_port (LV2_Handle instance, uint32_t port, void *data)
 {
 	BShapr* inst = (BShapr*) instance;
-	inst->connect_port (port, data);
+	if (inst) inst->connect_port (port, data);
 }
 
-void run (LV2_Handle instance, uint32_t n_samples)
+static void run (LV2_Handle instance, uint32_t n_samples)
 {
 	BShapr* inst = (BShapr*) instance;
-	inst->run (n_samples);
+	if (inst) inst->run (n_samples);
 }
 
-void cleanup (LV2_Handle instance)
+static void cleanup (LV2_Handle instance)
 {
 	BShapr* inst = (BShapr*) instance;
-	delete inst;
+	if (inst) delete inst;
 }
 
 static LV2_State_Status state_save(LV2_Handle instance, LV2_State_Store_Function store, LV2_State_Handle handle, uint32_t flags,
@@ -1598,7 +1600,7 @@ static LV2_State_Status state_restore(LV2_Handle instance, LV2_State_Retrieve_Fu
            const LV2_Feature* const* features)
 {
 	BShapr* inst = (BShapr*)instance;
-	inst->state_restore (retrieve, handle, flags, features);
+	if (inst) inst->state_restore (retrieve, handle, flags, features);
 	return LV2_STATE_SUCCESS;
 }
 
@@ -1611,7 +1613,7 @@ static const void* extension_data(const char* uri)
   return NULL;
 }
 
-const LV2_Descriptor descriptor =
+static const LV2_Descriptor descriptor =
 {
 		BSHAPR_URI,
 		instantiate,
